@@ -22,7 +22,7 @@
 #include "core-impl/collections/support/CollectionManager.h"
 #include "core-impl/playlists/types/file/PlaylistFileSupport.h"
 #include "core/playlists/PlaylistFormat.h"
-#include "playlist/PlaylistModelStack.h"
+#include "playlist/PlaylistController.h"
 #include "playlistmanager/PlaylistManager.h"
 
 #include <kio/job.h> // KIO::listRecursive
