@@ -17,13 +17,13 @@
 #ifndef AMAROK_MOUNTPOINTMANAGER_H
 #define AMAROK_MOUNTPOINTMANAGER_H
 
-#include "Amarok.h"
-#include "amarok_export.h"
-#include "plugin/plugin.h"
-#include "PluginManager.h"
+#include "core/support/Amarok.h"
+#include "core/support/PluginFactory.h"
+#include "shared/amarok_export.h"
 
-#include <KConfig>
+#include <KConfigGroup>
 #include <KUrl>
+#include <KPluginInfo>
 #include <solid/device.h>
 #include <threadweaver/Job.h>
 
@@ -33,15 +33,18 @@
 
 class DeviceHandler;
 class DeviceHandlerFactory;
+class SqlStorage;
 
 typedef QList<int> IdList;
 typedef QList<DeviceHandlerFactory*> FactoryList;
 typedef QMap<int, DeviceHandler*> HandlerMap;
 
-class AMAROK_EXPORT DeviceHandlerFactory : public Amarok::Plugin
+class AMAROK_EXPORT DeviceHandlerFactory : public Plugins::PluginFactory
 {
+    Q_OBJECT
+
 public:
-    DeviceHandlerFactory() {}
+    DeviceHandlerFactory( QObject *parent, const QVariantList &args );
     virtual ~DeviceHandlerFactory() {}
 
     /**
@@ -64,11 +67,11 @@ public:
      * @param volume the Volume for which a DeviceHandler is required
      * @return a DeviceHandler or 0 if the factory cannot handle the Medium
      */
-    virtual DeviceHandler* createHandler( const Solid::Device &device, const QString &udi ) const = 0;
+    virtual DeviceHandler* createHandler( const Solid::Device &device, const QString &udi, SqlStorage *s ) const = 0;
 
     virtual bool canCreateFromConfig() const = 0;
 
-    virtual DeviceHandler* createHandler( KSharedConfigPtr c ) const = 0;
+    virtual DeviceHandler* createHandler( KSharedConfigPtr c, SqlStorage *s ) const = 0;
 
     /**
      * returns the type of the DeviceHandler. Should be the same as the value used in
@@ -76,14 +79,13 @@ public:
      * @return a QString describing the type of the DeviceHandler
      */
     virtual QString type() const = 0;
-
 };
 
 /**
  *
  *
  */
-class DeviceHandler
+class AMAROK_EXPORT DeviceHandler
 {
 public:
     DeviceHandler() {}
@@ -139,38 +141,28 @@ public:
 /**
  *	@author Maximilian Kossick <maximilian.kossick@googlemail.com>
  */
-class MountPointManager : public QObject
+class AMAROK_EXPORT MountPointManager : public QObject
 {
-Q_OBJECT
-
+    Q_OBJECT
 
 public:
-    //the methods of this class a called *very* often. make sure they are as fast as possible
-    // (inline them?)
-
-    /**
-     * factory method.
-     * @return a MountPointManager instance
-     */
-    AMAROK_EXPORT static MountPointManager *instance();
-
-    /**
-     * frees the singleton
-     */
-    AMAROK_EXPORT static void destroy();
+    MountPointManager( QObject *parent, SqlStorage *storage );
+    ~MountPointManager();
 
     /**
      *
      * @param url
      * @return
      */
-    AMAROK_EXPORT int getIdForUrl( const KUrl &url );
+    virtual int getIdForUrl( const KUrl &url );
+
     /**
      *
      * @param id
      * @return
      */
-    QString getMountPointForId( const int id ) const;
+    virtual QString getMountPointForId( const int id ) const;
+
     /**
      * builds the absolute path from the mount point of the medium and the given relative
      * path.
@@ -178,24 +170,26 @@ public:
      * @param relativePath relative path on the medium
      * @return the absolute path
      */
-    void getAbsolutePath( const int deviceId, const KUrl& relativePath, KUrl& absolutePath ) const;
-    AMAROK_EXPORT QString getAbsolutePath ( const int deviceId, const QString& relativePath ) const;
+    virtual QString getAbsolutePath( const int deviceId, const QString& relativePath ) const;
+
     /**
      * calculates a file's/directory's relative path on a given device.
      * @param deviceId the unique id which identifies the device the file/directory is supposed to be on
      * @param absolutePath the file's/directory's absolute path
      * @param relativePath the calculated relative path
      */
-    void getRelativePath( const int deviceId, const KUrl& absolutePath, KUrl& relativePath ) const;
-    AMAROK_EXPORT QString getRelativePath( const int deviceId, const QString& absolutePath ) const;
+    virtual QString getRelativePath( const int deviceId, const QString& absolutePath ) const;
+
     /**
      * allows calling code to access the ids of all active devices
      * @return the ids of all devices which are currently mounted or otherwise accessible
      */
-    AMAROK_EXPORT IdList getMountedDeviceIds() const;
+    virtual IdList getMountedDeviceIds() const;
 
-    AMAROK_EXPORT QStringList collectionFolders();
-    void setCollectionFolders( const QStringList &folders );
+    virtual QStringList collectionFolders() const;
+    virtual void setCollectionFolders( const QStringList &folders );
+
+    void loadDevicePlugins( const QList<Plugins::PluginFactory*> &factories );
 
 public slots:
 //     void mediumAdded( const Medium *m );
@@ -206,7 +200,7 @@ public slots:
 //     void mediumChanged( const Medium* m );
 //     void mediumRemoved( const Medium* m );
 
-    void updateStatisticsURLs( bool changed = true );
+    virtual void updateStatisticsURLs( bool changed = true );
 
 signals:
     void deviceAdded( int id );
@@ -218,9 +212,6 @@ private slots:
     void startStatisticsUpdateJob();
 
 private:
-    static MountPointManager* s_instance;
-    MountPointManager();
-    ~MountPointManager();
 
     /**
      * checks whether a medium identified by its unique database id is currently mounted.
@@ -229,7 +220,8 @@ private:
      * @return true if the medium is mounted, false otherwise
      */
     bool isMounted ( const int deviceId ) const;
-    void init();
+
+    SqlStorage *m_storage;
     /**
      * maps a device id to a mount point. does only work for mountable filesystems and needs to be
      * changed for the real Dynamic Collection implementation.
@@ -259,4 +251,9 @@ private:
     void updateLabels();
 };
 
+#define AMAROK_EXPORT_DEVICE_PLUGIN(libname, classname) \
+K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
+K_EXPORT_PLUGIN(factory("amarok_device_" #libname))\
+
+
 #endif
