@@ -21,16 +21,21 @@
 #include "CollectionTreeItemModel.h"
 
 #include <amarokconfig.h>
+#include "AmarokMimeData.h"
 #include "CollectionTreeItem.h"
 #include "core/support/Debug.h"
 #include "core/support/Amarok.h"
 #include "core/collections/Collection.h"
-#include "core-impl/collections/support/CollectionManager.h"
+#include "core/collections/CollectionLocation.h"
 #include "core/collections/QueryMaker.h"
+#include "core/meta/Meta.h"
+#include "core-impl/collections/support/CollectionManager.h"
+#include "core-impl/collections/support/FileCollectionLocation.h"
 
 #include <KLocale>
 
 #include <QTimer>
+#include <QMap>
 
 CollectionTreeItemModel::CollectionTreeItemModel( const QList<int> &levelType )
     : CollectionTreeItemModelBase()
@@ -89,6 +94,17 @@ CollectionTreeItemModel::setLevels( const QList<int> &levelType )
         QTimer::singleShot( 0, this, SLOT( requestCollectionsExpansion() ) );
 }
 
+Qt::ItemFlags
+CollectionTreeItemModel::flags( const QModelIndex &idx ) const
+{
+    Qt::ItemFlags flags = CollectionTreeItemModelBase::flags( idx );
+    //TODO: check for CollectionLocation::isWritable().
+    if( !idx.parent().isValid() )
+        return flags | Qt::ItemIsDropEnabled;
+    else
+        return flags;
+}
+
 QVariant
 CollectionTreeItemModel::data(const QModelIndex &index, int role) const
 {
@@ -100,6 +116,65 @@ CollectionTreeItemModel::data(const QModelIndex &index, int role) const
     return dataForItem( item, role, item->level() - 1 );
 }
 
+bool
+CollectionTreeItemModel::dropMimeData( const QMimeData *data, Qt::DropAction action, int row,
+                                  int column, const QModelIndex &parent )
+{
+    if( !parent.isValid() && row == -1 && column == -1 )
+        return true; //only droppable on root (collection header) items.
+
+    CollectionTreeItem *item = static_cast<CollectionTreeItem*>( parent.internalPointer() );
+    Q_ASSERT(item->type() == CollectionTreeItem::Collection);
+
+    Collections::CollectionLocation *targetLocation = item->parentCollection()->location();
+    Q_ASSERT(targetLocation);
+
+    //TODO: accept external drops.
+    const AmarokMimeData *mimeData = qobject_cast<const AmarokMimeData *>( data );
+    Q_ASSERT(mimeData);
+
+    //TODO: optimize for copy from same provider.
+    Meta::TrackList tracks = mimeData->tracks();
+    QMap<const Collections::Collection *, Meta::TrackPtr> collectionTrackMap;
+
+    foreach( Meta::TrackPtr track, tracks )
+    {
+        const Collections::Collection *sourceCollection = track->collection();
+        collectionTrackMap.insertMulti( sourceCollection, track );
+    }
+
+    foreach( const Collections::Collection *sourceCollection, collectionTrackMap.uniqueKeys() )
+    {
+        Collections::CollectionLocation *sourceLocation;
+        if( sourceCollection )
+        {
+            sourceLocation = sourceCollection->location();
+            Q_ASSERT(sourceLocation);
+        }
+        else
+        {
+            sourceLocation = new Collections::FileCollectionLocation();
+        }
+
+        if( sourceLocation == targetLocation )
+            continue;
+
+        if( action == Qt::CopyAction )
+        {
+            sourceLocation->prepareCopy( collectionTrackMap.values( sourceCollection ),
+                                        targetLocation );
+        }
+        else if( action == Qt::MoveAction )
+        {
+            sourceLocation->prepareMove( collectionTrackMap.values( sourceCollection ),
+                                        targetLocation );
+        }
+    }
+
+    return true;
+}
+
+
 bool
 CollectionTreeItemModel::canFetchMore( const QModelIndex &parent ) const
 {
@@ -124,6 +199,7 @@ void
 CollectionTreeItemModel::collectionAdded( Collections::Collection *newCollection )
 {
     DEBUG_BLOCK
+
     if ( !newCollection )
         return;
 
@@ -133,6 +209,8 @@ CollectionTreeItemModel::collectionAdded( Collections::Collection *newCollection
     if ( d->collections.contains( collectionId ) )
         return;
 
+    debug() << "Added collection id:" << collectionId;
+
     //inserts new collection at the end.
     beginInsertRows( QModelIndex(), m_rootItem->childCount(), m_rootItem->childCount() );
     d->collections.insert( collectionId, CollectionRoot( newCollection, new CollectionTreeItem( newCollection, m_rootItem, this ) ) );
@@ -145,6 +223,10 @@ CollectionTreeItemModel::collectionAdded( Collections::Collection *newCollection
 void
 CollectionTreeItemModel::collectionRemoved( const QString &collectionId )
 {
+    DEBUG_BLOCK
+
+    debug() << "Removed collection id:" << collectionId;
+
     int count = m_rootItem->childCount();
     for( int i = 0; i < count; i++ )
     {
