@@ -67,12 +67,6 @@ class TabsEngine : public DataEngine
         void resultUltimateGuitarSearch( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
         void resultUltimateGuitarTab( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
 
-        /**
-        *   handling of tab data search results from fretplay.com
-        */
-        void resultFretplaySearch( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
-        void resultFretplayTab( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
-
         /**
         *   This method will send the info to the applet and order them if every jobs are finished
         */
@@ -95,11 +89,6 @@ class TabsEngine : public DataEngine
          */
         void queryUltimateGuitar( const QString &artist, const QString &title );
 
-        /**
-         *   starts a tab search at fretplay.com
-         */
-        void queryFretplay( const QString &artist, const QString &title );
-
         /**
          * The currently playing track
          */
