@@ -18,6 +18,8 @@
 
 #include "DaapCollection.h"
 
+#include <Solid/Networking>
+
 using namespace Meta;
 
 DaapTrack::DaapTrack( Collections::DaapCollection *collection, const QString &host, quint16 port, const QString &dbId, const QString &itemId, const QString &format)
@@ -75,6 +77,10 @@ DaapTrack::prettyUrl() const
 bool
 DaapTrack::isPlayable() const
 {
+    //daap tracks are accessed over the network, so check if network connectivity is present
+    if( Solid::Networking::status() != Solid::Networking::Connected )
+        return false;
+
     return true;
 }
 
