@@ -247,7 +247,6 @@ MediaDeviceHandler::removeMediaDeviceTrackFromCollection( Meta::MediaDeviceTrack
     year->remTrack( track );
 
     // if empty, get rid of metadata in general
-
     if( artist->tracks().isEmpty() )
     {
         artistMap.remove( artist->name() );
@@ -285,9 +284,18 @@ MediaDeviceHandler::removeMediaDeviceTrackFromCollection( Meta::MediaDeviceTrack
     }
 
     // remove from trackmap
-    trackMap.remove( track->name() );
+    trackMap.remove( track->uidUrl() );
+
+    m_titlemap.remove( track->name(), TrackPtr::staticCast( track ) );
+
+    // Finally, assign the created maps to the collection
     m_memColl->memoryCollection()->acquireWriteLock();
     m_memColl->memoryCollection()->setTrackMap( trackMap );
+    m_memColl->memoryCollection()->setArtistMap( artistMap );
+    m_memColl->memoryCollection()->setAlbumMap( albumMap );
+    m_memColl->memoryCollection()->setGenreMap( genreMap );
+    m_memColl->memoryCollection()->setComposerMap( composerMap );
+    m_memColl->memoryCollection()->setYearMap( yearMap );
     m_memColl->memoryCollection()->releaseLock();
 }
 
@@ -677,12 +685,7 @@ MediaDeviceHandler::slotFinalizeTrackRemove( const Meta::TrackPtr & track )
         m_wc->setDatabaseChanged();
     }
 
-    // remove from titlemap
-
-    m_titlemap.remove( track->name(), track );
-
-    // remove from collection
-
+    // remove from memory collection
     removeMediaDeviceTrackFromCollection( devicetrack );
 
     emit incrementProgress();
@@ -947,12 +950,12 @@ MediaDeviceHandler::privateParseTracks()
         }
 
         // When the provider saves a playlist, the handler should save it internally
-        connect( m_provider, SIGNAL( playlistSaved( const Playlists::MediaDevicePlaylistPtr &, const QString& ) ),
-                 SLOT( savePlaylist( const Playlists::MediaDevicePlaylistPtr &, const QString& ) ) );
-        connect( m_provider, SIGNAL( playlistRenamed( const Playlists::MediaDevicePlaylistPtr &) ),
-                 SLOT( renamePlaylist( const Playlists::MediaDevicePlaylistPtr & ) ) );
-        connect( m_provider, SIGNAL( playlistsDeleted( const Playlists::MediaDevicePlaylistList & ) ),
-                 SLOT( deletePlaylists( const Playlists::MediaDevicePlaylistList &  ) ) );
+        connect( m_provider, SIGNAL(playlistSaved(Playlists::MediaDevicePlaylistPtr,QString)),
+                 SLOT(savePlaylist(Playlists::MediaDevicePlaylistPtr,QString)) );
+        connect( m_provider, SIGNAL(playlistRenamed(Playlists::MediaDevicePlaylistPtr)),
+                 SLOT(renamePlaylist(Playlists::MediaDevicePlaylistPtr)) );
+        connect( m_provider, SIGNAL(playlistsDeleted(Playlists::MediaDevicePlaylistList)),
+                 SLOT(deletePlaylists(Playlists::MediaDevicePlaylistList)) );
 
         The::playlistManager()->addProvider(  m_provider,  m_provider->category() );
         m_provider->sendUpdated();
@@ -1048,7 +1051,6 @@ MediaDeviceHandler::freeSpace() const
 float
 MediaDeviceHandler::usedcapacity() const
 {
-    DEBUG_BLOCK
     if ( m_rcb )
         return m_rcb->usedCapacity();
     else
@@ -1058,7 +1060,6 @@ MediaDeviceHandler::usedcapacity() const
 float
 MediaDeviceHandler::totalcapacity() const
 {
-    DEBUG_BLOCK
     if ( m_rcb )
         return m_rcb->totalCapacity();
     else
