@@ -29,6 +29,7 @@ class MEDIADEVICECOLLECTION_EXPORT WriteCapability : public Handler::WriteCapabi
     Q_OBJECT
 
     public:
+        WriteCapability( QObject *parent ) : WriteCapabilityBase( parent ) {}
         virtual ~WriteCapability();
 
         /**
@@ -93,6 +94,7 @@ class MEDIADEVICECOLLECTION_EXPORT WriteCapability : public Handler::WriteCapabi
         virtual void libSetRating( Meta::MediaDeviceTrackPtr &track, int rating )  = 0;
         virtual void libSetType( Meta::MediaDeviceTrackPtr &track, const QString& type ) = 0;
         virtual void libSetPlayableUrl( Meta::MediaDeviceTrackPtr &destTrack, const Meta::TrackPtr &srcTrack ) = 0;
+        virtual void libSetIsCompilation( Meta::MediaDeviceTrackPtr &track, bool isCompilation );
         virtual void libSetCoverArt( Meta::MediaDeviceTrackPtr &track, const QImage &cover ) = 0;
 };
 }
