@@ -48,6 +48,9 @@
 #include <kmimetype.h>
 #include <KUrl>
 
+#include <QThread>
+#include <QTimer>
+
 AMAROK_EXPORT_COLLECTION( UmsCollectionFactory, umscollection )
 
 UmsCollectionFactory::UmsCollectionFactory( QObject *parent, const QVariantList &args )
@@ -145,6 +148,7 @@ UmsCollection::UmsCollection( Solid::Device device )
     , m_mc( new MemoryCollection() )
     , m_initialized( false )
     , m_autoConnect( false )
+    , m_musicFilenameScheme( "%artist%/%album%/%track% %title%" )
     , m_vfatSafe( true )
     , m_asciiOnly( false )
     , m_ignoreThe( false )
@@ -165,7 +169,7 @@ UmsCollection::UmsCollection( Solid::Device device )
 
     m_parseAction = new QAction( KIcon( "checkbox" ), i18n(  "&Use as Collection" ), this );
     m_parseAction->setProperty( "popupdropper_svg_id", "edit" );
-    connect( m_parseAction, SIGNAL( triggered() ), this, SLOT( slotParseTracks() ) );
+    connect( m_parseAction, SIGNAL( triggered() ), this, SLOT( slotParseActionTriggered() ) );
 
     m_ejectAction = new QAction( KIcon( "media-eject" ), i18n( "&Disconnect Device" ),
                                  const_cast<UmsCollection*>( this ) );
@@ -219,7 +223,10 @@ UmsCollection::init()
             }
             else if( line.startsWith( s_musicFilenameSchemeKey + "=" ) )
             {
-                m_musicFilenameScheme = line.section( '=', 1, 1 );
+                QString scheme = line.section( '=', 1, 1 );
+                //protect against empty setting.
+                if( !scheme.isEmpty() )
+                    m_musicFilenameScheme = scheme;
                 debug() << QString( "filename scheme: %1" ).arg( m_musicFilenameScheme );
             }
             else if( line.startsWith( s_vfatSafeKey + "=" ) )
@@ -274,7 +281,7 @@ UmsCollection::init()
     m_initialized = true;
 
     if( m_autoConnect )
-        slotParseTracks();
+        QTimer::singleShot( 0, this, SLOT(slotParseTracks()) );
 }
 
 void
@@ -402,10 +409,12 @@ UmsCollection::createCapabilityInterface( Capabilities::Capability::Type type )
     {
         case Capabilities::Capability::Actions:
         {
-            QList< QAction* > actions;
+            QList<QAction *> actions;
             if( m_initialized )
             {
-                actions << m_parseAction;
+                //HACK: use a bool or something else less unsafe
+                if( m_mc->trackMap().isEmpty() )
+                    actions << m_parseAction;
                 actions << m_configureAction;
                 actions << m_ejectAction;
             }
@@ -466,13 +475,19 @@ UmsCollection::slotParseTracks()
     {
         m_scanManager = new GenericScanManager( this );
         connect( m_scanManager, SIGNAL(directoryScanned( CollectionScanner::Directory * )),
-                SLOT(slotDirectoryScanned(CollectionScanner::Directory*)) );
-        connect( m_scanManager, SIGNAL(succeeded()), SIGNAL(updated()) );
+                SLOT(slotDirectoryScanned(CollectionScanner::Directory*)), Qt::DirectConnection );
     }
 
     m_scanManager->requestFullScan( QList<KUrl>() << m_musicPath );
 }
 
+void
+UmsCollection::slotParseActionTriggered()
+{
+    if( m_mc->trackMap().isEmpty() )
+        QTimer::singleShot( 0, this, SLOT(slotParseTracks()) );
+}
+
 void
 UmsCollection::slotConfigure()
 {
@@ -531,7 +546,10 @@ UmsCollection::slotConfigure()
                 m_musicPath = settings->m_musicFolder->url();
                 //TODO: reparse music
             }
-            m_musicFilenameScheme = filenameLayoutDialog.getParsableScheme().simplified();
+            QString scheme = filenameLayoutDialog.getParsableScheme().simplified();
+            //protect against empty string.
+            if( !scheme.isEmpty() )
+                m_musicFilenameScheme = scheme;
         }
         else
         {
@@ -566,7 +584,7 @@ UmsCollection::slotConfigure()
 
         m_autoConnect = settings->m_autoConnect->isChecked();
         if( !m_musicPath.isEmpty() && m_autoConnect )
-            slotParseTracks();
+            QTimer::singleShot( 0, this, SLOT(slotParseTracks()) );
 
         //write the date to the on-disk file
         KUrl localFile = KUrl( m_mountPoint );
@@ -636,5 +654,7 @@ UmsCollection::slotDirectoryScanned( CollectionScanner::Directory *dir )
         slotTrackAdded( scannerTrack->path() );
     }
 
+    emit updated();
+
     //TODO: read playlists
 }
