@@ -62,6 +62,7 @@ XSPFPlaylist::XSPFPlaylist()
     root.appendChild( createElement( "trackList" ) );
 
     appendChild( root );
+
 }
 
 XSPFPlaylist::XSPFPlaylist( const KUrl &url, bool autoAppend )
@@ -91,6 +92,7 @@ XSPFPlaylist::XSPFPlaylist( const KUrl &url, bool autoAppend )
     {
         The::playlistManager()->downloadPlaylist( m_url, PlaylistFilePtr( this ) );
     }
+
 }
 
 XSPFPlaylist::XSPFPlaylist( Meta::TrackList tracks )
@@ -206,13 +208,35 @@ XSPFPlaylist::trackCount() const
     if( m_tracksLoaded )
         return m_tracks.count();
 
-    //TODO: lookup in XML directly, without loading tracks
-    return -1;
+    int trackCount = 0;
+
+    QDomNode trackList = documentElement().namedItem( "trackList" );
+    QDomNode subNode = trackList.firstChild();
+    QDomNode subSubNode;
+
+    while( !subNode.isNull() )
+    {
+        subSubNode = subNode.firstChild();
+        if( subNode.nodeName() == "track" )
+        {
+            trackCount++;
+
+            while( !subSubNode.isNull() )
+                subSubNode = subSubNode.nextSibling();
+        }
+        subNode = subNode.nextSibling();
+    }
+
+    return trackCount;
 }
 
 Meta::TrackList
 XSPFPlaylist::tracks()
 {
+    //If you do not load before, m_tracks
+    //can be empty before usage.
+    triggerTrackLoad();
+
     return m_tracks;
 }
 
@@ -305,8 +329,6 @@ XSPFPlaylist::triggerTrackLoad()
 void
 XSPFPlaylist::addTrack( Meta::TrackPtr track, int position )
 {
-    if( !m_tracksLoaded )
-        triggerTrackLoad();
 
     Meta::TrackList trackList = tracks();
     int trackPos = position < 0 ? trackList.count() : position;
