@@ -58,12 +58,10 @@ class AMAROK_CORE_EXPORT EditablePlaylistCapability : public Capability
         virtual void setTrackList( Meta::TrackList trackList, bool append = false ) { Q_UNUSED( trackList ); Q_UNUSED( append ); };
 
         /** The playlist object should not store changed meta data immediately but cache the
-        changes until endMetaDataUpdate() or abortMetaDataUpdate() is called */
+        changes until endMetaDataUpdate() is called */
         virtual void beginMetaDataUpdate() = 0;
         /** All meta data has been updated and the object should commit the changed */
         virtual void endMetaDataUpdate() = 0;
-        /** Abort the meta data update without committing the changes */
-        virtual void abortMetaDataUpdate() = 0;
 
 };
 
