@@ -38,6 +38,7 @@
 #include "MusicBrainzTagger.h"
 #include "core/meta/support/MetaUtility.h"
 #include "core/collections/QueryMaker.h"
+#include "SvgHandler.h"
 #include "TagGuesser.h"
 #include "ui_TagDialogBase.h"
 
@@ -357,7 +358,7 @@ TagDialog::accept() //SLOT
 inline void
 TagDialog::openPressed() //SLOT
 {
-    new KRun( QFileInfo( m_path ).absolutePath(), this );
+    new KRun( m_path, this );
 }
 
 
@@ -814,14 +815,16 @@ TagDialog::setTagsToUi( const QVariantMap &tags )
     setControlsAccessability();
 
     // If it's a local file, write the directory to m_path, else disable the "open in konqui" button
-    KUrl url = tags.value( Meta::Field::URL ).toString();
+    QString urlString = tags.value( Meta::Field::URL ).toString();
+    KUrl url( urlString );
     //pathOrUrl will give localpath or proper url for remote.
     ui->kLineEdit_location->setText( url.pathOrUrl() );
     if( url.isLocalFile() )
     {
         ui->locationLabel->show();
         ui->kLineEdit_location->show();
-        m_path = url.directory( KUrl::AppendTrailingSlash );
+        QFileInfo fi( urlString );
+        m_path = fi.isDir() ? urlString : url.directory( KUrl::AppendTrailingSlash );
         ui->pushButton_open->setEnabled( true );
     }
     else
@@ -1191,7 +1194,7 @@ TagDialog::updateButtons()
 void
 TagDialog::updateCover()
 {
-    DEBUG_BLOCK;
+    DEBUG_BLOCK
 
     if( !m_currentTrack )
         return;
@@ -1219,8 +1222,7 @@ TagDialog::updateCover()
     else
     {
         ui->pixmap_cover->setVisible( true );
-
-        ui->pixmap_cover->setPixmap( QPixmap::fromImage( album->image( s ) ) );
+        ui->pixmap_cover->setPixmap( The::svgHandler()->imageWithBorder( album, s ) );
         QString artist = m_currentTrack->artist() ? m_currentTrack->artist()->name() : QString();
         ui->pixmap_cover->setInformation( artist, album->name() );
     }
