@@ -68,6 +68,7 @@ Dynamic::DynamicModel::instance()
 
 Dynamic::DynamicModel::DynamicModel(QObject* parent)
     : QAbstractItemModel( parent )
+    , m_activePlaylistIndex( 0 )
 { }
 
 Dynamic::DynamicModel::~DynamicModel()
@@ -1120,7 +1121,7 @@ static QString
 biasToString( Dynamic::BiasPtr bias, int level )
 {
     QString result;
-    result += QString(" ").repeated(level) + bias->toString() + " " + QString::number(ulong(bias.data()), 16) + "\n";
+    result += QString(" ").repeated(level) + bias->toString() + " " + QString::number(quintptr(bias.data()), 16) + "\n";
     if( Dynamic::AndBias* aBias = qobject_cast<Dynamic::AndBias*>(bias.data()) )
     {
         foreach( Dynamic::BiasPtr bias2, aBias->biases() )
@@ -1136,7 +1137,7 @@ Dynamic::DynamicModel::toString()
 
     foreach( Dynamic::DynamicPlaylist* playlist, m_playlists )
     {
-        result += playlist->title() + " " + QString::number(ulong(playlist), 16) + "\n";
+        result += playlist->title() + " " + QString::number(quintptr(playlist), 16) + "\n";
         if( Dynamic::BiasedPlaylist* bPlaylist = qobject_cast<Dynamic::BiasedPlaylist*>(playlist ) )
             result += biasToString( bPlaylist->bias(), 1 );
     }
