@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2009 Téo Mrnjavac <teo.mrnjavac@gmail.com>                             *
+ * Copyright (c) 2009 Téo Mrnjavac <teo@kde.org>                                        *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -18,18 +18,28 @@
 #define PLAYLISTVIEWURLGENERATOR_H
 
 #include "amarok_export.h"
+#include "AmarokUrlGenerator.h"
 #include "AmarokUrl.h"
 
 namespace Playlist
 {
 
-class AMAROK_EXPORT ViewUrlGenerator
+class AMAROK_EXPORT ViewUrlGenerator : public AmarokUrlGenerator
 {
 public:
+
+    static ViewUrlGenerator * instance();
+
+    QString description();
+    KIcon icon();
+    AmarokUrl createUrl();
+
+private:
+
     ViewUrlGenerator();
     virtual ~ViewUrlGenerator();
-
-    AmarokUrl createAmarokUrl();
+    
+    static ViewUrlGenerator * s_instance;
 };
 
 }
