@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2008-2010 Soren Harward <stharward@gmail.com>                          *
+ * Copyright (c) 2008-2011 Soren Harward <stharward@gmail.com>                          *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -55,14 +55,6 @@ class ConstraintNode : public QObject {
     Q_OBJECT
     public:
         enum NodeType { ConstraintGroupType, ConstraintType };
-        enum Operations { OperationInsert, OperationReplace, OperationDelete, OperationSwap };
-
-        typedef struct {
-            Operations operation;
-            int place;
-            int other; // for swaps
-            Meta::TrackPtr track;
-        } Vote;
 
         virtual ~ConstraintNode();
 
@@ -82,22 +74,13 @@ class ConstraintNode : public QObject {
         virtual void toXml( QDomDocument&, QDomElement& ) const = 0;
 
         // Set up the initial query for the ConstraintSolver
-        virtual Collections::QueryMaker* initQueryMaker( Collections::QueryMaker* ) const = 0;
+        virtual Collections::QueryMaker* initQueryMaker( Collections::QueryMaker* qm ) const { return qm; }
 
-        // Mathematical functions called by the ConstraintSolver
-        virtual double satisfaction( const Meta::TrackList& ) = 0;
-        virtual double deltaS_insert( const Meta::TrackList&, const Meta::TrackPtr, const int ) const = 0;
-        virtual double deltaS_replace( const Meta::TrackList&, const Meta::TrackPtr, const int ) const = 0;
-        virtual double deltaS_delete( const Meta::TrackList&, const int ) const = 0;
-        virtual double deltaS_swap( const Meta::TrackList&, const int, const int ) const = 0;
-        virtual void insertTrack( const Meta::TrackList&, const Meta::TrackPtr, const int ) = 0;
-        virtual void replaceTrack( const Meta::TrackList&, const Meta::TrackPtr, const int ) = 0;
-        virtual void deleteTrack( const Meta::TrackList&, const int ) = 0;
-        virtual void swapTracks( const Meta::TrackList&, const int, const int ) = 0;
+        // Mathematical function called by the ConstraintSolver
+        virtual double satisfaction( const Meta::TrackList& ) const = 0;
 
         // heuristic functions for the ConstraintSolver
-        virtual int suggestInitialPlaylistSize() const;
-        virtual Vote* vote( const Meta::TrackList&, const Meta::TrackList& ) const;
+        virtual quint32 suggestInitialPlaylistSize() const;
 
 #ifndef KDE_NO_DEBUG_OUTPUT
         virtual void audit(const Meta::TrackList&) const {}
