@@ -38,9 +38,11 @@
 #include <QTemporaryFile>
 #include <QToolBar>
 
+#include <KAction>
 #include "kio/jobclasses.h"
 #include <KCMultiDialog>
 #include <KStandardDirs>
+#include <KToolBar>
 #include "klocalizedstring.h"
 
 AMAROK_EXPORT_SERVICE_PLUGIN( amazonstore, AmazonServiceFactory )
@@ -93,6 +95,8 @@ AmazonStore::AmazonStore( AmazonServiceFactory* parent, const char *name )
     setObjectName( name );
 
     m_polished = false;
+    m_isNavigation = false;
+
     setShortDescription( i18n( "Access the Amazon MP3 Store directly from Amarok" ) );
     setIcon( KIcon( "view-services-amazon-amarok" ) );
 
@@ -115,7 +119,7 @@ AmazonStore::AmazonStore( AmazonServiceFactory* parent, const char *name )
     connect( m_searchWidget, SIGNAL( filterChanged( const QString ) ), this, SLOT( newSearchRequest( const QString ) ) );
 
     emit( ready() );
-    newSearchRequest( QString() ); // to get some default content
+    newSearchRequest( QLatin1String( "" ) ); // to get some default content
 }
 
 AmazonStore::~AmazonStore()
@@ -152,13 +156,15 @@ void
 AmazonStore::addToCart()
 {
     QString asin, name, price;
+    int id = 0;
 
     // get item from collection
     if( m_itemModel->isAlbum( m_selectedIndex ) ) // album
     {
         Meta::AmazonAlbum* album;
-        // row == albumId
-        album = dynamic_cast<Meta::AmazonAlbum*>( m_collection->albumById( m_selectedIndex.row() + 1 ).data() );
+        id = m_itemModel->idForIndex( m_selectedIndex );
+
+        album = dynamic_cast<Meta::AmazonAlbum*>( m_collection->albumById( id ).data() );
 
         if( !album )
             return;
@@ -170,9 +176,8 @@ AmazonStore::addToCart()
     else // track
     {
         Meta::AmazonTrack* track;
-        int id = m_selectedIndex.row() - m_collection->albumIDMap()->size() + m_itemModel->hiddenAlbums();
-        // row == albumId
-        track = dynamic_cast<Meta::AmazonTrack*>( m_collection->trackById( id + 1 ).data() );
+        id = m_itemModel->idForIndex( m_selectedIndex );
+        track = dynamic_cast<Meta::AmazonTrack*>( m_collection->trackById( id ).data() );
 
         if( !track )
             return;
@@ -223,11 +228,13 @@ AmazonStore::itemDoubleClicked( QModelIndex index )
     // for albums: search for the album name to get details about it
     // for tracks: add it to the playlist
 
+    int id = 0;
+
     if( m_itemModel->isAlbum( index ) ) // album
     {
         Meta::AmazonAlbum* album;
-        // row == albumId
-        album = dynamic_cast<Meta::AmazonAlbum*>( m_collection->albumById( m_selectedIndex.row() + 1 ).data() );
+        id = m_itemModel->idForIndex( index );
+        album = dynamic_cast<Meta::AmazonAlbum*>( m_collection->albumById( id ).data() );
 
         if( !album )
             return;
@@ -238,9 +245,8 @@ AmazonStore::itemDoubleClicked( QModelIndex index )
     else // track
     {
         Meta::AmazonTrack* track;
-        int id = index.row() - m_collection->albumIDMap()->size() + m_itemModel->hiddenAlbums() ;
-        // row == albumId
-        track = dynamic_cast<Meta::AmazonTrack*>( m_collection->trackById( id + 1 ).data() );
+        id = m_itemModel->idForIndex( index );
+        track = dynamic_cast<Meta::AmazonTrack*>( m_collection->trackById( id ).data() );
 
         if( !track )
             return;
@@ -277,14 +283,30 @@ AmazonStore::newSearchRequest( const QString request )
         if( !(KCM.exec() == QDialog::Accepted) )
             return;
     }
+    else if( AmazonConfig::instance()->country() == QLatin1String( "none" ) )
+    {
+        // user explicitly said we are in a not supported country
+        Amarok::Components::logger()->longMessage( i18n( "<b>MP3 Music Store</b><br/><br/>Please select a valid country in the settings to make the store work." ) );
+        return;
+    }
 
     if( m_lastSearch != request )
     {
+        // only add the request to the stack if it's a new one
+        if( !m_isNavigation )
+            m_backStack.push( m_lastSearch );
+
         // we start by showing the first result page
         m_lastSearch = request;
         m_resultpageSpinBox->setValue( 1 );
     }
 
+    m_isNavigation = false;
+
+    // update actions status
+    m_backwardAction->setEnabled( !m_backStack.isEmpty() );
+    m_forwardAction->setEnabled( !m_forwardStack.isEmpty() );
+
     // create request fetcher thread
     debug() << "Amazon: newSearchRequest: " << request;
     QUrl requestUrl = createRequestUrl( request );
@@ -320,16 +342,21 @@ AmazonStore::searchForAlbum( QModelIndex index )
     if( !m_itemModel->isAlbum( index ) ) // track
     {
         Meta::AmazonTrack* track;
-        int id = index.row() - m_collection->albumIDMap()->size() + m_itemModel->hiddenAlbums() ;
+        int id = m_itemModel->idForIndex( index );
 
-        // row == albumId
-        track = dynamic_cast<Meta::AmazonTrack*>( m_collection->trackById( id + 1 ).data() );
+        track = dynamic_cast<Meta::AmazonTrack*>( m_collection->trackById( id ).data() );
 
         if( !track )
             return;
 
-        QString name = m_collection->artistById( track->artistId() )->name() + " - ";
-        name =  name + m_collection->albumById( track->albumId() )->name();
+        QString name;
+
+        // don't add the artist name for compilations
+        if( !m_collection->albumById( track->albumId() )->isCompilation() )
+            name = m_collection->artistById( track->artistId() )->name() + " - ";
+
+        name = name + m_collection->albumById( track->albumId() )->name();
+
         m_searchWidget->setSearchString( name );
     }
 }
@@ -361,6 +388,19 @@ AmazonStore::createRequestUrl( QString request )
 void
 AmazonStore::initTopPanel()
 {
+    KHBox *topPanel = new KHBox( m_topPanel );
+    delete m_searchWidget;
+
+    KToolBar *navigationToolbar = new KToolBar( topPanel );
+    navigationToolbar->setToolButtonStyle( Qt::ToolButtonIconOnly );
+    navigationToolbar->setIconDimensions( 16 );
+
+    m_backwardAction = KStandardAction::back( this, SLOT( back() ), topPanel );
+    m_forwardAction = KStandardAction::forward( this, SLOT( forward() ), topPanel );
+    m_backwardAction->setEnabled( false );
+    m_forwardAction->setEnabled( false );
+
+    m_searchWidget = new SearchWidget( topPanel, false );
     m_searchWidget->setTimeout( 1500 );
     m_searchWidget->showAdvancedButton( false );
 
@@ -368,10 +408,10 @@ AmazonStore::initTopPanel()
     m_resultpageSpinBox->setMinimum( 1 );
     m_resultpageSpinBox->setToolTip( i18n( "Select results page to show" ) );
 
+    navigationToolbar->addAction( m_backwardAction );
+    navigationToolbar->addAction( m_forwardAction );
     m_searchWidget->toolBar()->addWidget( m_resultpageSpinBox );
 
-    m_searchWidget->toolBar()->addSeparator();
-
     connect( m_resultpageSpinBox, SIGNAL( valueChanged( int ) ), this, SLOT( newSpinBoxSearchRequest( int ) ) );
 }
 
@@ -383,6 +423,7 @@ AmazonStore::initView()
     m_itemView->setParent( this );
     m_itemView->setRootIsDecorated( false ); // items cannot be expanded
     m_itemView->setUniformRowHeights( true ); // for perf reasons
+    m_itemView->setFrameStyle( QFrame::NoFrame ); // no frame around the view, especially when selecting items
     m_itemView->setModel( m_itemModel );
 
     KHBox* bottomPanelLayout = new KHBox;
@@ -394,7 +435,7 @@ AmazonStore::initView()
     m_addToCartButton->setEnabled( false );
     m_addToCartButton->setObjectName( "addToCartButton" );
     m_addToCartButton->setParent( bottomPanelLayout );
-    //m_downloadAlbumButton->setIcon( KIcon( "addToCart-amarok" ) );
+    m_addToCartButton->setIcon( KIcon( "amarok_cart_add" ) );
 
     m_viewCartButton = new QPushButton;
     m_viewCartButton->setText( i18nc( "View your shopping cart contents", "View Cart" ) );
@@ -402,7 +443,7 @@ AmazonStore::initView()
     m_viewCartButton->setEnabled( true );
     m_viewCartButton->setObjectName( "viewCartButton" );
     m_viewCartButton->setParent( bottomPanelLayout );
-    //m_downloadAlbumButton->setIcon( KIcon( "viewCartButton-amarok" ) );
+    m_viewCartButton->setIcon( KIcon( "amarok_cart_view" ) );
 
     m_checkoutButton = new QPushButton;
     m_checkoutButton->setText( i18nc( "Checkout your shopping cart", "Checkout" ) );
@@ -410,7 +451,7 @@ AmazonStore::initView()
     m_checkoutButton->setEnabled( false );
     m_checkoutButton->setObjectName( "checkoutButton" );
     m_checkoutButton->setParent( bottomPanelLayout );
-    //m_downloadAlbumButton->setIcon( KIcon( "checkoutButton-amarok" ) );
+    m_checkoutButton->setIcon( KIcon( "download-amarok" ) );
 
     connect( m_addToCartButton, SIGNAL( clicked() ), this, SLOT( addToCart() ) );
     connect( m_itemView, SIGNAL( addToCart() ), this, SLOT( addToCart() ) );
@@ -513,12 +554,35 @@ AmazonStore::openCheckoutUrl( KJob* requestJob )
 
     // now that's the whole parser for this reply:
     QUrl url;
-    url.setEncodedUrl( responseDocument.documentElement().elementsByTagName( QString( "purchaseurl" ) ).at( 0 ).firstChild().nodeValue().toAscii() );
+    url.setEncodedUrl( responseDocument.documentElement().elementsByTagName( QLatin1String( "purchaseurl" ) ).at( 0 ).firstChild().nodeValue().toAscii() );
 
-    qDebug() << url;
     QDesktopServices::openUrl( url );
 
     requestJob->deleteLater();
     QFile::remove( tempFileName );
     AmazonCart::instance()->clear();
 }
+
+void
+AmazonStore::back()
+{
+    if( m_backStack.isEmpty() )
+        return;
+
+    QString request = m_backStack.pop();
+    m_forwardStack.push( m_lastSearch );
+    m_isNavigation = true;
+    m_searchWidget->setSearchString( request );
+}
+
+void
+AmazonStore::forward()
+{
+    if( m_forwardStack.isEmpty() )
+        return;
+
+    QString request = m_forwardStack.pop();
+    m_backStack.push( m_lastSearch );
+    m_isNavigation = true;
+    m_searchWidget->setSearchString( request );
+}
