@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2006,2007 Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>               *
+ * Copyright (c) 2006,2007 Nikolaj Hald Nielsen <nhn@kde.org>                           *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -16,9 +16,9 @@
 
 #include "MagnatuneDatabaseHandler.h"
 
-#include "collection/CollectionManager.h"
-#include "Debug.h"
-#include "collection/SqlStorage.h"
+#include "core-impl/collections/support/CollectionManager.h"
+#include "core/support/Debug.h"
+#include "core/collections/support/SqlStorage.h"
 
 using namespace Meta;
 
@@ -126,6 +126,7 @@ MagnatuneDatabaseHandler::destroyDatabase( )
     result = sqlDb->query( "DROP TABLE magnatune_moods;" );
 
 
+    /* that would only work for db2/oracle. Other databases connect the index to the table (which we just dropped)
     result = sqlDb->query( "DROP INDEX magnatune_tracks_artist_id;");
     result = sqlDb->query( "DROP INDEX magnatune_tracks_album_id;");
     result = sqlDb->query( "DROP INDEX magnatune_album_name;");
@@ -133,6 +134,7 @@ MagnatuneDatabaseHandler::destroyDatabase( )
     result = sqlDb->query( "DROP INDEX magnatune_artist_name;");
     result = sqlDb->query( "DROP INDEX magnatune_genre_album_id;");
     result = sqlDb->query( "DROP INDEX magnatune_genre_name;");
+    */
 
    /* if ( sqlDb->type() == DbConnection::postgresql )
     {
