@@ -16,9 +16,11 @@
 
 #include "ScriptableServiceCollection.h"
 
-#include "Debug.h"
+#include "core/support/Debug.h"
 #include "ScriptableServiceQueryMaker.h"
 
+using namespace Collections;
+
 ScriptableServiceCollection::ScriptableServiceCollection( const QString &name )
     : ServiceCollection( 0, name, name )
 {
@@ -31,7 +33,7 @@ ScriptableServiceCollection::~ScriptableServiceCollection()
 {
 }
 
-QueryMaker * ScriptableServiceCollection::queryMaker()
+Collections::QueryMaker * ScriptableServiceCollection::queryMaker()
 {
     return new ScriptableServiceQueryMaker( this, m_name );
 }
