@@ -339,16 +339,7 @@ AFTTagger::handleOgg( TagLib::Ogg::File *file )
         return false;
     }
 
-    TagLib::Ogg::XiphComment *comment = 0;
-    TagLib::Ogg::FLAC::File* flacFile;
-    TagLib::Ogg::Speex::File* speexFile;
-    TagLib::Ogg::Vorbis::File* vorbisFile;
-    if( ( flacFile = dynamic_cast<TagLib::Ogg::FLAC::File*>( file ) ) )
-        comment = flacFile->tag();
-    else if( ( speexFile = dynamic_cast<TagLib::Ogg::Speex::File*>( file ) ) )
-        comment = speexFile->tag();
-    else if( ( vorbisFile = dynamic_cast<TagLib::Ogg::Vorbis::File*>( file ) ) )
-        comment = vorbisFile->tag();
+    TagLib::Ogg::XiphComment *comment = dynamic_cast<TagLib::Ogg::XiphComment *>( file->tag() );
 
     if( !comment )
         return false;
