@@ -28,6 +28,12 @@
 #include <QStringList>
 #include <QXmlStreamWriter>
 
+#ifndef UTILITIES_BUILD
+    #include "amarok_export.h"
+#else
+    #define AMAROK_EXPORT
+#endif
+
 class QSharedMemory;
 
 namespace CollectionScanner
@@ -38,7 +44,7 @@ namespace CollectionScanner
     We are using a shared memory that the amarok process holds open until the scanning
     is finished to store the state.
  */
-class ScanningState
+class AMAROK_EXPORT ScanningState
 {
     public:
         ScanningState();
